@@ -1,7 +1,7 @@
 /* GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999, 2006, 2010  Ales Cepek <cepek@fsv.cvut.cz>
                   2011  Vaclav Petras <wenzeslaus@gmail.com>
-                  2012, 2013, 2014, 2015, 2018, 2019, 2020
+                  2012, 2013, 2014, 2015, 2018, 2019, 2020, 2021
                   Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
@@ -36,6 +36,7 @@
 
 #include <gnu_gama/local/network.h>
 #include <gnu_gama/local/local_linearization.h>
+#include <gnu_gama/local/test_linearization_visitor.h>
 #include <gnu_gama/local/itstream.h>
 #include <gnu_gama/local/skipcomm.h>
 #include <gnu_gama/statan.h>
@@ -47,7 +48,6 @@
 using namespace std;
 using namespace GNU_gama::local;
 
-
 typedef std::list<GNU_gama::Cluster<Observation>*> ClusterList;
 typedef GNU_gama::Cluster<Observation>             Cluster_;  // 1.10
 
@@ -335,6 +335,23 @@ void LocalNetwork::set_max_linearization_iterations(int value)
 }
 
 
+bool LocalNetwork::refine_adjustment()
+{
+  clear_linearization_iterations();
+  while (next_linearization_iterations())
+    {
+      bool refine = refine_obsdh_reductions(this);
+      if (!refine) refine = TestLinearization(this);
+      if (!refine) break;
+
+      increment_linearization_iterations();
+      refine_approx_coordinates();
+    }
+
+  return linearization_iterations() > 0;
+}
+
+
 double LocalNetwork::epoch() const
 {
   return epoch_;
@@ -984,7 +1001,7 @@ int LocalNetwork::null_space()
     {
       if (vs.error() != GNU_gama::Exception::BadRegularization) throw;
 
-      for (int i=1; i<=sum_unknowns(); i++)
+      for (int i=1; i<=unknowns_count(); i++)
         if (lindep(i))
           {
             const char    type = unknown_type(i);
@@ -1039,11 +1056,11 @@ void LocalNetwork::std_error_ellipse(const PointID& cb,
 // 1.7.09 added optional update of constrained coordinates; inspired
 // by adjustment of photographic observation by Jim Sutherland
 
-void LocalNetwork::refine_approx()
+void LocalNetwork::refine_approx_coordinates()
 {
   const Vec& x = least_squares->unknowns();
 
-  for (int i=1; i<=sum_unknowns(); i++)
+  for (int i=1; i<=unknowns_count(); i++)
     if (unknown_type(i) == 'X')
       {
         const PointID& cb = unknown_pointid(i);
@@ -1159,11 +1176,11 @@ void LocalNetwork::vyrovnani_()
   do {
 
     project_equations();
-    if (sum_unknowns()     == 0)
+    if (unknowns_count()     == 0)
       throw GNU_gama::local::Exception(T_GaMa_No_unknowns_defined);
-    if (sum_observations() == 0)
+    if (observations_count() == 0)
       throw GNU_gama::local::Exception(T_GaMa_No_observations_available);
-    if (sum_points()      == 0)
+    if (points_count()      == 0)
       throw GNU_gama::local::Exception(T_GaMa_No_points_available);
 
     tst_vyrovnani_ = true;
@@ -1310,7 +1327,7 @@ void LocalNetwork::vyrovnani_()
 }
 
 
-std::string LocalNetwork::updated_xml()
+std::string LocalNetwork::export_xml()
 {
   if (!is_adjusted()) std::string();
 
@@ -1335,7 +1352,7 @@ std::string LocalNetwork::updated_xml()
 
   xml += " angles=";
   xml += PD.left_handed_angles() ? "\"left-handed\"" : "\"right-handed\"";
-  if (has_epoch()) xml += " epoch=\"" + std::to_string(epoch()) + "\"";
+  if (has_epoch()) xml += " epoch=\"" + to_xmlstr(epoch()) + "\"";
   xml += ">\n";
 
 
@@ -1343,26 +1360,30 @@ std::string LocalNetwork::updated_xml()
     xml += "\n<description>" + description + "</description>\n";
 
   xml += "\n<parameters\n";
-  xml += "  sigma-apr=\"" + std::to_string(apriori_m_0()) + "\"\n";
-  xml += "  conf-pr=\""   + std::to_string(conf_pr())     + "\"\n";
-  xml += "  tol-abs=\""   + std::to_string(tol_abs())     + "\"\n";
+  xml += "  sigma-apr=\"" + to_xmlstr(apriori_m_0()) + "\"\n";
+  xml += "  conf-pr=\""   + to_xmlstr(conf_pr())     + "\"\n";
+  xml += "  tol-abs=\""   + to_xmlstr(tol_abs())     + "\"\n";
   xml += "  sigma-act=\"";
   xml +=         m_0_apriori() ? "apriori\"\n" : "aposteriori\"\n";
   xml += "  angles=\"" + std::string(gons() ? "400" : "360") + "\"\n";
   if (has_algorithm()) xml += "  algorithm=\"" + algorithm() + "\"\n";
   if (has_latitude())
-    xml += "  latitude=\"" + std::to_string(latitude()) + "\"\n";
+    xml += "  latitude=\"" + to_xmlstr(latitude()) + "\"\n";
   if (has_ellipsoid()) xml += "  ellipsoid=\"" + ellipsoid() + "\"\n";
-  xml += "  cov-band=\"" + std::to_string(adj_covband()) + "\"\n";
+  xml += "  cov-band=\"" + to_xmlstr(adj_covband()) + "\"\n";
   // iterations ... not implemented in XML input
   // language .....
   // encoding .....
   xml += "/>\n";
 
 
-  xml += "\n<points-observations";
+  xml += "\n<points-observations \n";
   // implicit parameters
-  xml += ">\n\n";
+  // xml += "   distance-stdev=  '5.0' \n";
+  // xml += "   direction-stdev= '10.0' \n";
+  // xml += "   angle-stdev=     '10.0' \n";
+  // xml += "   azimuth-stdev=   '10.0' \n";
+  xml += "   >\n\n";
 
 
   for (auto p=PD.begin(); p!=PD.end(); ++p)
@@ -1374,12 +1395,12 @@ std::string LocalNetwork::updated_xml()
       xml += "<point id=\"" + id.str() + "\"";
 
       if (point.test_xy()) {
-        xml += " x=\"" + std::to_string(point.x()) + "\"";
-        xml += " y=\"" + std::to_string(point.y()) + "\"";
+        xml += " x=\"" + to_xmlstr(point.x(), 16) + "\"";
+        xml += " y=\"" + to_xmlstr(y_sign()*point.y(), 16) + "\"";
       }
 
       if (point.test_z()) {
-          xml += " z=\"" + std::to_string(point.z()) + "\"";
+          xml += " z=\"" + to_xmlstr(point.z()) + "\"";
       }
 
       std::string fix {}, adj {};
@@ -1403,7 +1424,13 @@ std::string LocalNetwork::updated_xml()
   for (auto c=OD.clusters.begin(); c!=OD.clusters.end(); ++c) {
     if (auto cluster = dynamic_cast<StandPoint*>(*c))
       {
-        xml += "\n<obs from=\"" + cluster->station.str() + "\">\n";
+        auto cluster_from = cluster->station.str();
+        xml += "\n<obs";
+        if (!cluster_from.empty())
+          {
+            xml += " from=\"" + cluster->station.str() + "\"";
+          }
+        xml += ">\n";
 
         for (auto p  = cluster->observation_list.begin();
                   p != cluster->observation_list.end(); ++p) {
@@ -1411,12 +1438,18 @@ std::string LocalNetwork::updated_xml()
           obs->accept(&info);
 
           xml += "<" +  info.xml_name;
+          if (!info.str_from.empty()) {
+              if (cluster_from != info.str_from) {
+                  xml += " from=\"" + info.str_from + "\"";
+                }
+            }
           if (!info.str_to.empty()) {
             xml += " to=\"" + info.str_to + "\"";
             double fdh = obs->from_dh();
             double tdh = obs->to_dh();
-            if (fdh) xml += " from_dh=\"" + std::to_string(fdh) + "\"";
-            if (tdh) xml +=   " to_dh=\"" + std::to_string(tdh) + "\"";
+            if (info.xml_name != "s-distance") fdh = tdh = 0;
+            if (fdh) xml += " from_dh=\"" + to_xmlstr(fdh) + "\"";
+            if (tdh) xml +=   " to_dh=\"" + to_xmlstr(tdh) + "\"";
           }
           else if (!info.str_bs.empty()) {
             xml += " bs=\"" + info.str_bs + "\"";
@@ -1426,9 +1459,9 @@ std::string LocalNetwork::updated_xml()
             double rdh = a->from_dh();
             double bdh = a->bs_dh();
             double fdh = a->fs_dh();
-            if (rdh) xml += " from_dh=\"" + std::to_string(rdh) + "\"";
-            if (bdh) xml +=   " bs_dh=\"" + std::to_string(bdh) + "\"";
-            if (fdh) xml +=   " fs_dh=\"" + std::to_string(fdh) + "\"";
+            if (rdh) xml += " from_dh=\"" + to_xmlstr(rdh) + "\"";
+            if (bdh) xml +=   " bs_dh=\"" + to_xmlstr(bdh) + "\"";
+            if (fdh) xml +=   " fs_dh=\"" + to_xmlstr(fdh) + "\"";
           }
           xml += " val=\"" + info.str_val + "\"";
           xml += " stdev=\"" + info.str_stdev + "\"";
@@ -1454,7 +1487,7 @@ std::string LocalNetwork::updated_xml()
          double dist = 0;
          if (H_Diff* p = dynamic_cast<H_Diff*>(obs)) dist = p->dist();
          if (dist > 0)
-           xml += " dist=\"" +std::to_string(dist) + "\"";
+           xml += " dist=\"" +to_xmlstr(dist) + "\"";
          else
            xml += " stdev=\"" + info.str_stdev + "\"";
          xml += "/>\n";
@@ -1477,6 +1510,7 @@ std::string LocalNetwork::updated_xml()
               xml += " x=\"" + info.str_val + "\"";
               ++p;
               (*p)->accept(&info);
+
               xml += " y=\"" + info.str_val + "\"";
               auto q = p;
               ++q;
@@ -1520,8 +1554,8 @@ std::string LocalNetwork::updated_xml()
 
           // double fdh = (*p)->from_dh(); ... unrealistic
           // double tdh = (*p)->to_dh();
-          // if (fdh) xml += " from_dh=\"" + std::to_string(fdh) + "\"";
-          // if (tdh) xml +=   " to_dh=\"" + std::to_string(tdh) + "\"";
+          // if (fdh) xml += " from_dh=\"" + xml_string(fdh) + "\"";
+          // if (tdh) xml +=   " to_dh=\"" + xml_string(tdh) + "\"";
           xml += " />\n";
         }
 
@@ -1550,8 +1584,8 @@ void LocalNetwork::updated_xml_covmat(std::string& xml, const CovMat& C,
   int  band = C.bandWidth();
   if (!always && band == 0) return;
 
-  xml += "\n<cov-mat dim=\"" + std::to_string(dim) + "\"";
-  xml += " band=\"" + std::to_string(band) + "\">\n";
+  xml += "\n<cov-mat dim=\"" + to_string(dim) + "\"";
+  xml += " band=\"" + to_string(band) + "\">\n";
   for (int i=1; i<=dim; i++)
     {
       std::ostringstream out;
