@@ -99,16 +99,16 @@ namespace GNU_gama { namespace local
     {
       return undefined_xy_z_;
     }
-    int sum_points()
+    int points_count()
     {
       revision_points(); return pocbod_;
     }
     void  revision_observations();
-    const ObservationList& sum_rejected_observations() const
+    const ObservationList& rejected_observations_count() const
     {
       return removed_obs;
     }
-    int sum_observations() const
+    int observations_count() const
     {
       return pocmer_;
     }
@@ -173,12 +173,12 @@ namespace GNU_gama { namespace local
       vyrovnani_();
       return r;
     }
-    int sum_unknowns()
+    int unknowns_count()
     {
       project_equations();
       return A.cols();
     }
-    int sum_observations()
+    int observations_count()
     {
       project_equations();
       return A.rows();
@@ -201,7 +201,7 @@ namespace GNU_gama { namespace local
     double cond();
     bool lindep(int i);
 
-    void refine_approx();
+    void refine_approx_coordinates();
 
     void   apriori_m_0(double m)  { m_0_apr_ = m; }
     void   tol_abs(double m)      { tol_abs_ = m; }
@@ -301,10 +301,14 @@ namespace GNU_gama { namespace local
     int  increment_linearization_iterations() { return ++iterations_; }
     bool next_linearization_iterations() const { return iterations_ < max_linearization_iterations_;}
 
-    // ...  input data with free coordinates updated after adjustment
-    //      and rejected observations removed ..............................
+    bool refine_adjustment();
 
-    std::string updated_xml();
+    std::string export_xml();
+
+    // ... verbose output ..................................................
+
+    void set_verbose(bool val=true) { verbose_ = val; }
+    bool verbose() const { return verbose_; };
 
     // #####################################################################
 
@@ -404,6 +408,8 @@ namespace GNU_gama { namespace local
     void change_y_signs_for_inconsistent_system_();
     bool removed_inconsistency_ {false};
 
+    bool verbose_ { false };
+
 
   };     /* class LocalNetwork */
 
